@@ -306,21 +306,20 @@ class NetSnmpQuery implements SnmpQueryInterface
      */
     public function translate(string $oid): string
     {
+        $oid = new Oid($oid);
         $this->options = array_diff($this->options, [self::DEFAULT_FLAGS]); // remove default options
 
-        $this->options[] = '-Pu'; // don't error on _
-
         // user did not specify numeric, output full text
         if (! in_array('-On', $this->options)) {
             if (! in_array('-Os', $this->options)) {
                 $this->options[] = '-OS'; // show full oid, unless hideMib is set
             }
-        } elseif (Oid::isNumeric($oid)) {
+        } elseif ($oid->isNumeric()) {
             return Str::start($oid, '.'); // numeric to numeric optimization
         }
 
         // if mib is not directly specified and it doesn't have a numeric root
-        if (! str_contains($oid, '::') && ! Oid::hasNumericRoot($oid)) {
+        if (! $oid->hasMib() && ! $oid->hasNumericRoot()) {
             $this->options[] = '-IR'; // search for mib
         }
 
