@@ -111,13 +111,21 @@ class Vrp extends OS implements
             if ($data['HUAWEI-ENTITY-EXTENT-MIB::hwEntityOpticalType'] === 'inactive') {
                 return null;
             }
+            if ($data['HUAWEI-ENTITY-EXTENT-MIB::hwEntityOpticalMode'] == 1) {
+                return null;
+            }
+
             // Skip when it is not a plugable optic
             if ($data['HUAWEI-ENTITY-EXTENT-MIB::hwEntityOpticalType'] === '0') {
                 return null;
             }
 
             // Handle cases where required data might not be available (fallback to null)
-            $cable = $data['HUAWEI-ENTITY-EXTENT-MIB::hwEntityOpticalConnectType'] ?? null;
+            $connector = $data['HUAWEI-ENTITY-EXTENT-MIB::hwEntityOpticalConnectType'] ?? null;
+            if ($connector == '-') {
+                $connector = null;
+            }
+
             $distance = $data['HUAWEI-ENTITY-EXTENT-MIB::hwEntityOpticalTransferDistance'] ?? '';
             if (preg_match_all("/(([0-9]+)\([^\)]+\))+/i", $distance, $matches)) {
                 $distance = intval(max($matches[2]));
@@ -148,9 +156,7 @@ class Vrp extends OS implements
             $typeToDesc = ['unknown', 'sc', 'gbic', 'sfp', 'esfp', 'rj45', 'xfp', 'xenpak', 'transponder', 'cfp', 'smb', 'sfpplus', 'cxp', 'qsfp', 'qsfpplus', 'cfp2', 'dwdmsfp', 'msa100glh', 'gps', 'csfp', 'cfp4', 'qsfp28', 'sfpsfpplus', 'gponsfp', 'cfp8', 'sfp28', 'qsfpdd', 'cfp2dco', 'sfp56', 'qsfp56', 'oa'];
 
             $mode = $data['HUAWEI-ENTITY-EXTENT-MIB::hwEntityOpticalMode'] ?? '';
-            $modeToText[1] = 'singleMode';
-            $modeToText[2] = 'multiMode5';
-            $modeToText[3] = 'multiMode6';
+            $modeToText = [null, 'notSupported', 'singleMode', 'multiMode5', 'multiMode6', 'noValue', 'gpsMode'];
             if (isset($modeToText[$mode])) {
                 $mode = ' ' . $modeToText[$mode];
             }
@@ -167,6 +173,10 @@ class Vrp extends OS implements
                 $type .= $mode;
             }
 
+            if (empty($data['HUAWEI-ENTITY-EXTENT-MIB::hwEntityOpticalVenderName']) && empty($data['HUAWEI-ENTITY-EXTENT-MIB::hwEntityOpticalVenderPn']) && empty($data['HUAWEI-ENTITY-EXTENT-MIB::hwEntityOpticalVendorSn'])) {
+                return null; //Probably no transceiver around here
+            }
+
             // Create a new Transceiver object with the retrieved data
             return new Transceiver([
                 'port_id' => $port_id,
@@ -175,8 +185,11 @@ class Vrp extends OS implements
                 'type' => $type,
                 'model' => $data['HUAWEI-ENTITY-EXTENT-MIB::hwEntityOpticalVenderPn'] ?? null,
                 'serial' => $data['HUAWEI-ENTITY-EXTENT-MIB::hwEntityOpticalVendorSn'] ?? null,
-                'cable' => $cable,
+                'connector' => $connector,
+                'revision' => null,
+                'cable' => null,
                 'distance' => $distance,
+                'date' => $data['HUAWEI-ENTITY-EXTENT-MIB::hwEntityOpticalManufacturedDate'] ?? null,
                 'wavelength' => $wavelength,
                 'entity_physical_index' => $entIndex,
             ]);
