@@ -25,33 +25,35 @@
 
 namespace LibreNMS\Util;
 
+use App\ConfigRepository;
 use Illuminate\Support\Arr;
 use Illuminate\Support\Facades\DB;
-use LibreNMS\Config;
 use LibreNMS\DB\Eloquent;
 use Symfony\Component\Process\Process;
 
 class Version
 {
     /** @var string Update this on release */
-    public const VERSION = '24.11.0';
+    public const VERSION = '24.12.0';
 
     /** @var Git convenience instance */
     public $git;
+    private ConfigRepository $config;
 
-    public function __construct()
+    public function __construct(ConfigRepository $config)
     {
+        $this->config = $config;
         $this->git = Git::make();
     }
 
     public static function get(): Version
     {
-        return new static;
+        return new static(app('librenms-config'));
     }
 
     public function release(): string
     {
-        return Config::get('update_channel') == 'master' ? 'master' : self::VERSION;
+        return $this->config->get('update_channel') == 'master' ? 'master' : self::VERSION;
     }
 
     public function date(string $format = 'c'): string
@@ -135,7 +137,7 @@ class Version
 
     public function rrdtool(): string
     {
-        $process = new Process([Config::get('rrdtool', 'rrdtool'), '--version']);
+        $process = new Process([$this->config->get('rrdtool', 'rrdtool'), '--version']);
         $process->run();
         preg_match('/^RRDtool ([\w.]+) /', $process->getOutput(), $matches);
 
@@ -144,7 +146,7 @@ class Version
 
     public function netSnmp(): string
     {
-        $process = new Process([Config::get('snmpget', 'snmpget'), '-V']);
+        $process = new Process([$this->config->get('snmpget', 'snmpget'), '-V']);
 
         $process->run();
         preg_match('/[\w.]+$/', $process->getErrorOutput(), $matches);
