@@ -264,7 +264,7 @@ class CheckSchemaStructure implements Validation, ValidationFixer
      */
     private function columnToSql(array $column_data): string
     {
-        $segments = ["`${column_data['Field']}`", $column_data['Type']];
+        $segments = ["`{$column_data['Field']}`", $column_data['Type']];
 
         $segments[] = $column_data['Null'] ? 'NULL' : 'NOT NULL';
 
@@ -274,7 +274,7 @@ class CheckSchemaStructure implements Validation, ValidationFixer
             } elseif ($column_data['Default'] == 'NULL') {
                 $segments[] = 'DEFAULT NULL';
             } else {
-                $segments[] = "DEFAULT '${column_data['Default']}'";
+                $segments[] = "DEFAULT '{$column_data['Default']}'";
             }
         }
 
