@@ -547,7 +547,6 @@ class Device extends BaseModel
     {
         return $query->where([
             ['status', '=', 0],
-            ['disable_notify', '=', 0],
             ['ignore', '=', 0],
             ['disabled', '=', 0],
         ]);
@@ -1030,6 +1029,11 @@ class Device extends BaseModel
         return $this->hasMany(LoadbalancerRserver::class, 'device_id');
     }
 
+    public function qos(): HasMany
+    {
+        return $this->hasMany(Qos::class, 'device_id');
+    }
+
     public function slas(): HasMany
     {
         return $this->hasMany(Sla::class, 'device_id');
