@@ -1,17 +1,25 @@
 <?php
 /*
+ * nxos.inc.php
+ *
  * LibreNMS NX-OS Fan state
  *
- * Copyright (c) 2016 Dave Bell <me@geordish.org>
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 3 of the License, or (at your
  * option) any later version.  Please see LICENSE.txt at the top level of
  * the source code distribution for details.
+ *
+ * @link        https://www.librenms.org
+ *
+ * @copyright   2016 Dave Bell <me@geordish.org>
+ * @author      Dave Bell <me@geordish.org>
+ *
+ * @copyright   2024 CTNET BV
+ * @author      Rudy Broersma <r.broersma@ctnet.nl>
  */
 
-$fan_tray_oid = '.1.3.6.1.4.1.9.9.117.1.4.1.1.1';
-$fan_trays = snmpwalk_cache_oid($device, $fan_tray_oid, []);
+$fan_trays = SnmpQuery::hideMib()->numeric(true)->walk('CISCO-ENTITY-FRU-CONTROL-MIB::cefcFanTrayOperStatus')->values(0);
 
 /* CISCO-ENTITY-FRU-CONTROL-MIB cefcFanTrayOperStatus
  *  unknown(1),
@@ -21,14 +29,12 @@ $fan_trays = snmpwalk_cache_oid($device, $fan_tray_oid, []);
 */
 
 if (is_array($fan_trays)) {
-    foreach ($fan_trays as $oid => $array) {
-        $state = current($array);
-        $split_oid = explode('.', $oid);
+    foreach ($fan_trays as $current_oid => $current_value) {
+        $split_oid = explode('.', $current_oid);
         $index = $split_oid[count($split_oid) - 1];
-        $current_oid = "$fan_tray_oid.$index";
 
         $entity_oid = '.1.3.6.1.2.1.47.1.1.1.1.7';
-        $descr = trim(snmp_get($device, "$entity_oid.$index", '-Ovq'), '"');
+        $descr = SnmpQuery::get('ENTITY-MIB::entPhysicalName.' . $index)->value();
 
         $state_name = 'cefcFanTrayOperStatus';
         $states = [
@@ -39,7 +45,8 @@ if (is_array($fan_trays)) {
         ];
         create_state_index($state_name, $states);
 
-        discover_sensor(null, 'state', $device, $current_oid, $index, $state_name, $descr, 1, 1);
+        discover_sensor(null, 'state', $device, $current_oid, $index, $state_name, $descr, 1, 1, null, null, null, null, $current_value);
+
         create_sensor_to_state_index($device, $state_name, $index);
     }
 }
