@@ -34,7 +34,7 @@ foreach ($modulation as $link => $linkEntry) {
         $index = "$link.$radio";
         if (isset($radioEntry['linkAcmRxModulation'])) {
             discover_sensor(
-                $valid['sensor'],
+                null,
                 'state',
                 $device,
                 ".1.3.6.1.4.1.3373.1103.80.17.1.6.$index",
@@ -46,7 +46,7 @@ foreach ($modulation as $link => $linkEntry) {
         }
         if (isset($radioEntry['linkAcmTxModulation'])) {
             discover_sensor(
-                $valid['sensor'],
+                null,
                 'state',
                 $device,
                 ".1.3.6.1.4.1.3373.1103.80.17.1.7.$index",
