@@ -9,8 +9,8 @@
  * the source code distribution for details.
  */
 require 'includes/html/graphs/common.inc.php';
-$rrdfilename = rrd_name($device['hostname'], 'cambium-epmp-gps');
-if (rrdtool_check_rrd_exists($rrdfilename)) {
+$rrdfilename = Rrd::name($device['hostname'], 'cambium-epmp-gps');
+if (Rrd::checkRrdExists($rrdfilename)) {
     $rrd_options .= " COMMENT:'dBm                Now       Ave      Max     \\n'";
     $rrd_options .= ' DEF:numTracked=' . $rrdfilename . ':numTracked:AVERAGE ';
     $rrd_options .= ' DEF:numVisible=' . $rrdfilename . ':numVisible:AVERAGE ';
