@@ -103,7 +103,7 @@ if (count($added_sources) > 0 || count($removed_sources) > 0) {
     $app->data = ['sources' => $sources]; // save sources
     $log_message = 'Chronyd Source Change:';
     $log_message .= count($added_sources) > 0 ? ' Added ' . implode(',', $added_sources) : '';
-    $log_message .= count($removed_sources) > 0 ? ' Removed ' . implode(',', $added_sources) : '';
+    $log_message .= count($removed_sources) > 0 ? ' Removed ' . implode(',', $removed_sources) : '';
     log_event($log_message, $device, 'application');
 }
 
